%define major		1
%define libname		%mklibname searpc %{major}
%define develname	%mklibname searpc -d

# checkout by commit for a valid persistent source link
# the corresponding git tag is v3.3-latest
%define commit		783141fb694f3bd1f8bd8a783670dd25a53b9fc1
%define date		20230527
%define shortcommit	%(c=%{commit}; echo ${c:0:7})

Name:		libsearpc
Version:	3.3.0
Release:	%mkrel 0.git%{date}.2
Summary:	Simple C language RPC framework based on GObject system
License:	GPLv3+
Group:		Networking/File transfer
URL:		https://github.com/haiwen/libsearpc
#Source0:	https://github.com/haiwen/libsearpc/archive/v%%{version}/%%{name}-%%{version}.tar.gz
Source0:	https://github.com/haiwen/libsearpc/archive/%{commit}/%{name}-%{version}%{?date:-%{date}git%{shortcommit}}.tar.gz
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(simplejson)

%description
Searpc is a simple C language RPC framework based on GObject system.
Searpc handles the serialization/deserialization part of RPC, the
transport part is left to users. It is part of seafile project.

#----------------------------------------------------

%package -n	%{libname}
Summary:	Simple C language RPC framework based on GObject system
Group:		System/Libraries
Requires:	python3dist(pysearpc) >= %{version}-%{release}

%description -n	%{libname}
Searpc is a simple C language RPC framework based on GObject system.
Searpc handles the serialization/deserialization part of RPC, the
transport part is left to users. It is part of seafile project.
This package contains library files for %{name}.

#----------------------------------------------------

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	searpc-devel = %{version}-%{release}

%description -n	%{develname}
The %{develname} package contains libraries and header files for
developing applications that use %{name}.

#----------------------------------------------------

%package -n	python3-pysearpc
Summary:	Python 3 bindings for %{name}
Group:		Development/Python
BuildArch:	noarch
Requires:	python3dist(simplejson)
Provides:	python3dist(pysearpc) = %{version}-%{release}
Provides:	python%{python3_version}dist(pysearpc) = %{version}-%{release}
%{?python_provide:%python_provide python3-pysearpc}

%description -n	python3-pysearpc
Searpc is a simple C language RPC framework based on GObject system.
Searpc handles the serialization/deserialization part of RPC, the
transport part is left to users. It is part of seafile project.
This package contains the python 3 bindings for %{name}.

#----------------------------------------------------

%prep
%setup -qn %{name}-%{commit}
%autopatch -p1

sed -i -e /\(DESTDIR\)/d libsearpc.pc.in

NOCONFIGURE=1 ./autogen.sh

%build
export PYTHON=%{__python3}

%configure \
	--disable-static \
	--disable-compile-demo \
	--with-python3
%make_build

%install
%make_install

# we don't want these
find %{buildroot} -name '*.la' -delete

# python shebangs
%py3_shebang_fix %{buildroot}%{_bindir}

%files -n %{libname}
%{_libdir}/libsearpc.so.%{major}{,.*}

%files -n %{develname}
%doc AUTHORS README.markdown
%license LICENSE*
%{_includedir}/*
%{_libdir}/libsearpc.so
%{_libdir}/pkgconfig/%{name}.pc

%files -n python3-pysearpc
%doc AUTHORS README.markdown
%{_bindir}/searpc-codegen.py
%{python3_sitearch}/pysearpc/


%changelog
* Wed Dec 20 2023 daviddavid <daviddavid> 3.3.0-0.git20230527.2.mga10
+ Revision: 2019945
- rebuild for py3.12

* Sat Oct 21 2023 daviddavid <daviddavid> 3.3.0-0.git20230527.1.mga10
+ Revision: 1999911
- update to latest 3.3 git branch

* Wed Nov 09 2022 daviddavid <daviddavid> 3.2.0-8.git20220425.1.mga9
+ Revision: 1904934
- update to latest 3.2 git branch

* Sat Mar 19 2022 umeabot <umeabot> 3.2.0-7.mga9
+ Revision: 1799657
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 3.2.0-6.mga9
+ Revision: 1774294
- rebuild for python-3.10

* Sat Mar 20 2021 daviddavid <daviddavid> 3.2.0-5.mga9
+ Revision: 1705252
- rebuild for python 3.9

* Mon Jun 08 2020 daviddavid <daviddavid> 3.2.0-4.mga8
+ Revision: 1590948
- re-upload tarball (upstream modified it without changing the release)

* Sun May 10 2020 daviddavid <daviddavid> 3.2.0-3.mga8
+ Revision: 1582761
- remove unneeded python2 build dependency on pkgconfig(pygobject-2.0)

* Mon Feb 17 2020 daviddavid <daviddavid> 3.2.0-2.mga8
+ Revision: 1537469
- fix python shebangs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 29 2019 daviddavid <daviddavid> 3.2.0-1.mga8
+ Revision: 1456508
- new version: 3.2.0

* Sun Sep 15 2019 daviddavid <daviddavid> 3.1.0-3.mga8
+ Revision: 1441118
- backport latest upstream fixes from git20190911 for python3 port
- switch to Python 3

* Fri Jan 25 2019 daviddavid <daviddavid> 3.1.0-2.mga7
+ Revision: 1360574
- backport some upstream fixes (fix_slow_log_unit )
- rename python-pysearpc to python2-pysearpc

* Thu Oct 11 2018 daviddavid <daviddavid> 3.1.0-1.mga7
+ Revision: 1319488
- new version: 3.1.0

* Sun Sep 23 2018 umeabot <umeabot> 3.1-4.mga7
+ Revision: 1299135
- Mageia 7 Mass Rebuild

* Sun Aug 19 2018 wally <wally> 3.1-3.mga7
+ Revision: 1252773
- loosen lib pkg requires

* Sun Aug 19 2018 wally <wally> 3.1-2.mga7
+ Revision: 1252747
- rebuild for aarch64

* Mon Oct 31 2016 daviddavid <daviddavid> 3.1-1.mga6
+ Revision: 1064294
- new version: 3.1

* Sat May 07 2016 daviddavid <daviddavid> 3.0.7-2.mga6
+ Revision: 1010163
- move requires python-pysearpc from devel subpackage to library subpackage

* Fri May 06 2016 daviddavid <daviddavid> 3.0.7-1.mga6
+ Revision: 1009872
- initial package libsearpc

